import typing
import pydantic


class EncryptedPaymentHeader(pydantic.BaseModel):
    """
    header information for Encrypted Data from ApplePay, GooglePay or Paze.
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    ephemeral_public_key: typing.Optional[str] = pydantic.Field(
        alias="ephemeralPublicKey", default=None
    )
    """
    Provides textual information about a cipher key for exchanging data via an associated string or byte image. This is a public key generated by the merchant and shared with Firm. In this context, this key is called ephemeral for its short life span.
    """
    public_key_hash: typing.Optional[str] = pydantic.Field(
        alias="publicKeyHash", default=None
    )
    """
    This is the hash output using a hash function for the Ephemeral Public Key.
    """
    wallet_application_data: typing.Optional[str] = pydantic.Field(
        alias="walletApplicationData", default=None
    )
    """
    Contain the data provided by merchant to the wallet provider.
    """
    wallet_transaction_id: typing.Optional[str] = pydantic.Field(
        alias="walletTransactionId", default=None
    )
    """
    Identifies a unique occurrence of a transaction.
    """
