import typing
import pydantic


class MerchantIdentification(pydantic.BaseModel):
    """
    Sub-Merchant Identification Information
    """

    model_config = pydantic.ConfigDict(
        arbitrary_types_allowed=True,
        populate_by_name=True,
    )

    seller_identifier: typing.Optional[str] = pydantic.Field(
        alias="sellerIdentifier", default=None
    )
    """
    A unique number generated by the Firm to identify the individual Transaction Division processing, using the American Express (AMEX) OptBlue program under the Firm's Service Entitlement (SE) Number. In the AMEX OptBlue program, the merchant does not have an SE Number with AMEX. The Firm owns the merchant relationship and provides all the merchant servicing and support.
    """
    service_entitlement_number: typing.Optional[str] = pydantic.Field(
        alias="serviceEntitlementNumber", default=None
    )
    """
    Identifies a unique number assigned to a merchant by a payment brand to process conveyed transactions.
    """
    sub_merchant_id: typing.Optional[str] = pydantic.Field(
        alias="subMerchantId", default=None
    )
    """
    Identifies a merchant's account as it appears on the accountholder's statement.
    """
