import typing
import typing_extensions
import pydantic


class MerchantIdentification(typing_extensions.TypedDict):
    """
    Sub-Merchant Identification Information
    """

    seller_identifier: typing_extensions.NotRequired[str]
    """
    A unique number generated by the Firm to identify the individual Transaction Division processing, using the American Express (AMEX) OptBlue program under the Firm's Service Entitlement (SE) Number. In the AMEX OptBlue program, the merchant does not have an SE Number with AMEX. The Firm owns the merchant relationship and provides all the merchant servicing and support.
    """

    service_entitlement_number: typing_extensions.NotRequired[str]
    """
    Identifies a unique number assigned to a merchant by a payment brand to process conveyed transactions.
    """

    sub_merchant_id: typing_extensions.NotRequired[str]
    """
    Identifies a merchant's account as it appears on the accountholder's statement.
    """


class _SerializerMerchantIdentification(pydantic.BaseModel):
    """
    Serializer for MerchantIdentification handling case conversions
    and file omissions as dictated by the API
    """

    model_config = pydantic.ConfigDict(
        populate_by_name=True,
    )

    seller_identifier: typing.Optional[str] = pydantic.Field(
        alias="sellerIdentifier", default=None
    )
    service_entitlement_number: typing.Optional[str] = pydantic.Field(
        alias="serviceEntitlementNumber", default=None
    )
    sub_merchant_id: typing.Optional[str] = pydantic.Field(
        alias="subMerchantId", default=None
    )
